@@ -1,8 +1,10 @@
 
-#' Estimate reliability estimates for multidimensional scales in the Bayesian framework
+#' Estimate Bayesian reliability estimates for multidimensional scales following a second-order factor model
 #' @description When supplying a multidimensional data set
 #' the function estimates the reliability of the set by means of omega_total
 #' and the general factor saturation of the set by means of omega_hierarchical.
+#' The data must follow a simple second-order factor model structure with no crossloadings
+#' and no error covariances. Otherwise the estimation will fail.
 #'
 #' The prior distributions of omega_t and omega_h are computed from
 #' the prior distributions of the second-order factor model.
@@ -19,13 +21,13 @@
 #' @param data A matrix or data.frame containing multivariate observations,
 #' rows = observations, columns = variables/items
 #' @param n.factors A number specifying the number of group factors that the items load on
-#' @param model A string that by default ("balanced") distributes the items evenly
+#' @param model A string that by default NULL (=balanced) distributes the items evenly
 #' among the number of group factors. This only works if the items are a multiple of
 #' the number of group factors and the items are already grouped in the data set,
 #' meaning, e.g., items 1-5 load on one factor, 6-10 on another, and so on.
 #' A model file can be specified in lavaan syntax style (f1=~.+.+.) to relate the items
-#' to the group factors. The items can either be named as the columns in the data set
-#' or x1, ..., xn, where 1,...,n correspond to the column numbers
+#' to the group factors. The items' names need to equal the column names in the data set,
+#' aka the variable names
 #' @param n.iter A number for the iterations of the Gibbs Sampler
 #' @param n.burnin A number for the burnin in the Gibbs Sampler
 #' @param n.chains A number for the chains to run for the MCMC sampling
@@ -64,30 +66,34 @@
 #' omega_t and omega_h
 #'
 #' @examples
-#' # note that the iterations are set very low for smoother running examples, you should use
-#' # at least the defaults
-#' res <- bomegas(upps, n.factors = 5, model = "balanced", n.iter = 200, n.burnin = 50,
-#' n.chains = 2, missing = "listwise")
-#'
-#' # or with specified model syntax relating the group factors to the items:
+#' # specify the model syntax relating the group factors to the items:
 #' model <- "f1 =~ U17_r + U22_r + U29_r + U34_r
 #' f2 =~ U4 + U14 + U19 + U27
 #' f3 =~ U6 + U16 + U28 + U48
 #' f4 =~ U23_r + U31_r + U36_r + U46_r
 #' f5 =~ U10_r + U20_r + U35_r + U52_r"
-#' res <- bomegas(upps, n.factors = 5, model = model, n.iter = 200, n.burnin = 50,
+#' # specifying the model can be omitted if the model structure is simple and balanced,
+#' # meaning the an equal number of items load on each factor, and the items relate to the factors
+#' # in the same order as they appear in the data.
+#' # Note that the iterations are set very low for smoother running examples, you should use
+#' # at least the defaults:
+#' res <- bomegas(upps, n.factors = 5, model = NULL, n.iter = 200, n.burnin = 50,
 #' n.chains = 2, missing = "listwise")
+#'
+
 #'
 #' @references{
 #'
 #' \insertRef{Lee2007}{Bayesrel}
 #'
 #'}
+#'
+#' @importFrom utils setTxtProgressBar txtProgressBar
 #' @export
 bomegas <- function(
   data,
   n.factors,
-  model = "balanced",
+  model = NULL,
   n.iter = 2e3,
   n.burnin = 200,
   n.chains = 3,
@@ -103,6 +109,13 @@ bomegas <- function(
   callback = function(){}
 ) {
 
+  # make sure only the data referenced in the model file is used, if a model file is specified
+  if (!is.null(model)) {
+    mod_opts <- modelSyntaxExtract(model, colnames(data))
+    data <- data[, mod_opts$var_names]
+  }
+
+  # deal with missings
   listwise <- FALSE
   pairwise <- FALSE
   complete_cases <- nrow(data)
@@ -123,10 +136,11 @@ bomegas <- function(
   if (is.null(p0)) p0 <- n.factors^2 - n.factors
   if (is.null(R0)) R0 <- ncol(data)
 
-  pb <- progress::progress_bar$new(total = n.iter * n.chains)
+  pb <- txtProgressBar(max = n.chains * n.iter, style = 3)
   sum_res <- bomegasMultiOut(data, n.factors, n.iter, n.burnin, thin, n.chains,
                              interval, model, pairwise, a0, b0, l0, A0, c0, d0, beta0, B0, p0, R0,
-                             param.out, callback, pbtick = pb$tick)
+                             param.out, callback, pbtick = pb)
+  close(pb)
 
   sum_res$complete_cases <- complete_cases
   sum_res$call <- match.call()
