@@ -9,22 +9,19 @@
 #include <limits.h>
 #include "declarations.h"
 
-void skip_to_end_of_line();
-int get_line();
-int max_line_length();
-void countentry();
-void addentry();
 
-int read_prob(fname,pn,pk,pC,pa,pconstraints,printlevel)
-     char *fname;
-     int *pn;
-     int *pk;
-     struct blockmatrix *pC;
-     double **pa;
-     struct constraintmatrix **pconstraints;
-     int printlevel;
-     
-{
+void skip_to_end_of_line(FILE *fid);
+int get_line(FILE *fid, char *buffer, int bufsiz);
+int max_line_length(FILE *fid);
+void countentry(struct constraintmatrix *constraints, int matno, int blkno,
+  int blocksize);
+void addentry(struct constraintmatrix *constraints, int matno, int blkno,
+  int indexi, int indexj, double ent);
+
+
+int read_prob(char *fname, int *pn, int *pk, struct blockmatrix *pC,
+	      double **pa, struct constraintmatrix **pconstraints,
+	      int printlevel) {
   struct constraintmatrix *myconstraints;
   FILE *fid;
   int i,j;
@@ -752,8 +749,7 @@ int read_prob(fname,pn,pk,pC,pa,pconstraints,printlevel)
  *  file fid.
  */
 
-void skip_to_end_of_line(fid)
-     FILE *fid;
+void skip_to_end_of_line(FILE *fid)
 {
   char c;
  
@@ -768,10 +764,7 @@ void skip_to_end_of_line(fid)
  *
  */
 
-int get_line(fid,buffer,bufsiz)
-     FILE *fid;
-     char *buffer;
-     int bufsiz;
+int get_line(FILE *fid,  char *buffer, int bufsiz)
 {
   int i;
   int k;
@@ -811,8 +804,7 @@ int get_line(fid,buffer,bufsiz)
   return(0);
 }
 
-int max_line_length(fid)
-     FILE *fid;
+int max_line_length(FILE *fid)
 {
   int maxlen;
   int k;
@@ -838,11 +830,7 @@ int max_line_length(fid)
 
 }
 
-void countentry(constraints,matno,blkno,blocksize)
-     struct constraintmatrix *constraints;
-     int matno;
-     int blkno;
-     int blocksize;
+void countentry(struct constraintmatrix *constraints, int matno, int blkno, int blocksize)
 {
   struct sparseblock *p;
   struct sparseblock *q;
@@ -929,13 +917,8 @@ void countentry(constraints,matno,blkno,blocksize)
 
 }
 
-void addentry(constraints,matno,blkno,indexi,indexj,ent)
-     struct constraintmatrix *constraints;
-     int matno;
-     int blkno;
-     int indexi;
-     int indexj;
-     double ent;
+void addentry(struct constraintmatrix *constraints, int matno, int blkno, int indexi,
+  int indexj, double ent)
 {
   struct sparseblock *p;
 
